YakoThemeSwitch class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- YakoThemeSwitch
Constructors
-
YakoThemeSwitch({Key? key, bool enabled = false, double width = 45, Color? enabledBackgroundColor, Color? disabledBackgroundColor, Color? enabledToggleColor, Color? disabledToggleColor, Duration animationDuration = const Duration(milliseconds: 500), required ValueChanged<
bool> onChanged, double? enabledToggleBorderRadius = 20}) -
const
Properties
- animationDuration → Duration
-
The duration of the animation
final
- disabledBackgroundColor → Color?
-
The background color of the switch when it is disabled
final
- disabledToggleColor → Color?
-
The color of the toggle when it is disabled
final
- enabled → bool
-
false: dark theme (left position), true: light theme (right position)
final
- enabledBackgroundColor → Color?
-
The background color of the switch when it is enabled
final
- enabledToggleBorderRadius → double?
-
The border radius of the toggle. Try setting it to 4 to make the circle square
final
- enabledToggleColor → Color?
-
The color of the toggle when it is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
bool> -
Callback invoked with the new state whenever the switch is toggled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
You can set the custom width of the switch
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< YakoThemeSwitch> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited